@@ -4,7 +4,7 @@ import (
 	"context"
 
 	"github.com/golang/glog"
-	mapiv1 "github.com/openshift/cluster-api/pkg/apis/machine/v1beta1"
+	mapiv1 "github.com/openshift/machine-api-operator/pkg/apis/machine/v1beta1"
 	"github.com/openshift/machine-api-operator/pkg/util/conditions"
 	v1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
